@@ -2,16 +2,21 @@
 function(u, v, cop=NULL, para=NULL,
                reflect=c("cop", "surv", "acute", "grave",
                            "1",    "2",     "3",     "4"), ...) {
-   reflect <- match.arg(reflect)
+
    if(is.list(para) && ! is.null(para$cop) && is.null(cop)) {
       # The third test is related to whether cop is incoming from
       # the top level of the function. This is a major thing to
-      # avoid overwritting the desired copula because
+      # avoid overwriting the desired copula because
       # is.null(para$cop) is fuzzy meaning is.null(para$c) passes too.
       if(! is.null(para$reflect)) reflect <- para$reflect
-      cop  <- para$cop
-      para <- para$para
+      if(! is.null(para$cop    )) cop     <- para$cop
+      if(! is.null(para$para   )) para    <- para$para
    }
+
+   reflect <- as.character(reflect) # so that numeric integers would
+   reflect <-    match.arg(reflect) #           silently be accepted
+
+   if(! is.list(para)) names(para) <- NULL # removes unsightly named labels often on the para in this package
    return(switch(reflect,
                  cop   =             cop(u,     v, para=para, ...),
                  surv  = u + v - 1 + cop(1-u, 1-v, para=para, ...),
